@@ -7,7 +7,7 @@ import pprint
 import time
 from typing import NewType
 
-import anki  # pylint: disable=unused-import
+import anki
 import anki.collection
 import anki.decks
 import anki.notes
@@ -48,6 +48,7 @@ class Card(DeprecatedNamesMixin):
     type: CardType
     memory_state: FSRSMemoryState | None
     desired_retention: float | None
+    decay: float | None
 
     def __init__(
         self,
@@ -101,6 +102,7 @@ class Card(DeprecatedNamesMixin):
         self.desired_retention = (
             card.desired_retention if card.HasField("desired_retention") else None
         )
+        self.decay = card.decay if card.HasField("decay") else None
 
     def _to_backend_card(self) -> cards_pb2.Card:
         # mtime & usn are set by backend
@@ -124,6 +126,7 @@ class Card(DeprecatedNamesMixin):
             custom_data=self.custom_data,
             memory_state=self.memory_state,
             desired_retention=self.desired_retention,
+            decay=self.decay,
         )
 
     @deprecated(info="please use col.update_card()")
@@ -172,10 +175,11 @@ class Card(DeprecatedNamesMixin):
 
     def template(self) -> TemplateDict:
         notetype = self.note_type()
+        templates = notetype["tmpls"]
         if notetype["type"] == MODEL_STD:
-            return self.note_type()["tmpls"][self.ord]
+            return templates[self.ord]
         else:
-            return self.note_type()["tmpls"][0]
+            return templates[0]
 
     def start_timer(self) -> None:
         self.timer_started = time.time()
