@@ -122,6 +122,7 @@ class ComputedMemoryState:
     desired_retention: float
     stability: float | None = None
     difficulty: float | None = None
+    decay: float | None = None
 
 
 @dataclass
@@ -157,7 +158,7 @@ class Collection(DeprecatedNamesMixin):
         self.tags = TagManager(self)
         self.conf = ConfigManager(self)
         self._load_scheduler()
-        self._startReps = 0  # pylint: disable=invalid-name
+        self._startReps = 0
 
     def name(self) -> Any:
         return os.path.splitext(os.path.basename(self.path))[0]
@@ -510,9 +511,7 @@ class Collection(DeprecatedNamesMixin):
     # Utils
     ##########################################################################
 
-    def nextID(  # pylint: disable=invalid-name
-        self, type: str, inc: bool = True
-    ) -> Any:
+    def nextID(self, type: str, inc: bool = True) -> Any:
         type = f"next{type.capitalize()}"
         id = self.conf.get(type, 1)
         if inc:
@@ -848,7 +847,6 @@ class Collection(DeprecatedNamesMixin):
         )
 
     def _pb_search_separator(self, operator: SearchJoiner) -> SearchNode.Group.Joiner.V:
-        # pylint: disable=no-member
         if operator == "AND":
             return SearchNode.Group.Joiner.AND
         else:
@@ -866,7 +864,9 @@ class Collection(DeprecatedNamesMixin):
                 return column
         return None
 
-    def browser_row_for_id(self, id_: int) -> tuple[
+    def browser_row_for_id(
+        self, id_: int
+    ) -> tuple[
         Generator[tuple[str, bool, BrowserRow.Cell.TextElideMode.V], None, None],
         BrowserRow.Color.V,
         str,
@@ -982,14 +982,14 @@ class Collection(DeprecatedNamesMixin):
         )
         return self.set_config(key, value, undoable=undoable)
 
-    def _get_enable_load_balancer(self) -> bool:
+    def _get_load_balancer_enabled(self) -> bool:
         return self.get_config_bool(Config.Bool.LOAD_BALANCER_ENABLED)
 
-    def _set_enable_load_balancer(self, value: bool) -> None:
-        self.set_config_bool(Config.Bool.LOAD_BALANCER_ENABLED, value)
+    def _set_load_balancer_enabled(self, value: bool) -> None:
+        self._backend.set_load_balancer_enabled(value)
 
     load_balancer_enabled = property(
-        fget=_get_enable_load_balancer, fset=_set_enable_load_balancer
+        fget=_get_load_balancer_enabled, fset=_set_load_balancer_enabled
     )
 
     def _get_enable_fsrs_short_term_with_steps(self) -> bool:
@@ -1189,9 +1189,13 @@ class Collection(DeprecatedNamesMixin):
                 desired_retention=resp.desired_retention,
                 stability=resp.state.stability,
                 difficulty=resp.state.difficulty,
+                decay=resp.decay,
             )
         else:
-            return ComputedMemoryState(desired_retention=resp.desired_retention)
+            return ComputedMemoryState(
+                desired_retention=resp.desired_retention,
+                decay=resp.decay,
+            )
 
     def fuzz_delta(self, card_id: CardId, interval: int) -> int:
         "The delta days of fuzz applied if reviewing the card in v3."
@@ -1207,8 +1211,6 @@ class Collection(DeprecatedNamesMixin):
     # the count on things like edits, which we probably could do by checking
     # the previous state in moveToState.
 
-    # pylint: disable=invalid-name
-
     def startTimebox(self) -> None:
         self._startTime = time.time()
         self._startReps = self.sched.reps
