@@ -73,6 +73,7 @@ langs = sorted(
         ("ଓଡ଼ିଆ", "or_OR"),
         ("Filipino", "tl"),
         ("ئۇيغۇر", "ug"),
+        ("Oʻzbek", "uz_UZ"),
     ]
 )
 
@@ -123,6 +124,7 @@ compatMap = {
     "th": "th_TH",
     "tr": "tr_TR",
     "uk": "uk_UA",
+    "uz": "uz_UZ",
     "vi": "vi_VN",
 }
 
@@ -157,13 +159,13 @@ def lang_to_disk_lang(lang: str) -> str:
 
 
 # the currently set interface language
-current_lang = "en"  # pylint: disable=invalid-name
+current_lang = "en"
 
 # the current Fluent translation instance. Code in pylib/ should
 # not reference this, and should use col.tr instead. The global
 # instance exists for legacy reasons, and as a convenience for the
 # Qt code.
-current_i18n: anki._backend.RustBackend | None = None  # pylint: disable=invalid-name
+current_i18n: anki._backend.RustBackend | None = None
 tr_legacyglobal = anki._backend.Translations(None)
 
 
@@ -178,7 +180,7 @@ def ngettext(single: str, plural: str, num: int) -> str:
 
 
 def set_lang(lang: str) -> None:
-    global current_lang, current_i18n  # pylint: disable=invalid-name
+    global current_lang, current_i18n
     current_lang = lang
     current_i18n = anki._backend.RustBackend(langs=[lang])
     tr_legacyglobal.backend = weakref.ref(current_i18n)
