@@ -3,6 +3,7 @@
 
 from __future__ import annotations
 
+import functools
 import json
 import math
 import re
@@ -37,6 +38,7 @@ from aqt.operations.note import remove_notes
 from aqt.operations.scheduling import (
     bury_cards,
     forget_cards,
+    grade_now,
     reposition_new_cards_dialog,
     set_due_date_dialog,
     suspend_cards,
@@ -51,10 +53,12 @@ from aqt.operations.tag import (
 from aqt.qt import *
 from aqt.sound import av_player
 from aqt.switch import Switch
+from aqt.theme import WidgetStyle
 from aqt.undo import UndoActionsInfo
 from aqt.utils import (
     HelpPage,
     KeyboardModifiersPressed,
+    add_close_shortcut,
     add_ellipsis_to_action_label,
     current_window,
     ensure_editor_saved,
@@ -167,6 +171,7 @@ class Browser(QMainWindow):
         if self.height() != 0:
             self.aspect_ratio = self.width() / self.height()
         self.set_layout(self.mw.pm.browser_layout(), True)
+        self.onSidebarVisibilityChange(not self.sidebarDockWidget.isHidden())
         # disable undo/redo
         self.on_undo_state_change(mw.undo_actions_info())
         # legacy alias
@@ -277,6 +282,19 @@ class Browser(QMainWindow):
         if note_type_id := self.get_active_note_type_id():
             add_cards.set_note_type(note_type_id)
 
+    # If in the Browser we open Preview and press Ctrl+W there,
+    # both Preview and Browser windows get closed by Qt out of the box.
+    # We circumvent that behavior by only closing the currently active window
+    def _handle_close(self):
+        active_window = QApplication.activeWindow()
+        if active_window and active_window != self:
+            if isinstance(active_window, QDialog):
+                active_window.reject()
+            else:
+                active_window.close()
+        else:
+            self.close()
+
     def setupMenus(self) -> None:
         # actions
         f = self.form
@@ -340,6 +358,7 @@ class Browser(QMainWindow):
         qconnect(f.action_Info.triggered, self.showCardInfo)
         qconnect(f.actionReposition.triggered, self.reposition)
         qconnect(f.action_set_due_date.triggered, self.set_due_date)
+        qconnect(f.action_grade_now.triggered, self.grade_now)
         qconnect(f.action_forget.triggered, self.forget_cards)
         qconnect(f.actionToggle_Suspend.triggered, self.suspend_selected_cards)
         qconnect(f.action_toggle_bury.triggered, self.bury_selected_cards)
@@ -362,6 +381,7 @@ class Browser(QMainWindow):
         qconnect(f.actionFind.triggered, self.onFind)
         qconnect(f.actionNote.triggered, self.onNote)
         qconnect(f.actionSidebar.triggered, self.focusSidebar)
+        qconnect(f.actionToggleSidebar.triggered, self.toggle_sidebar)
         qconnect(f.actionCardList.triggered, self.onCardList)
 
         # help
@@ -379,6 +399,7 @@ class Browser(QMainWindow):
 
         add_ellipsis_to_action_label(f.actionCopy)
         add_ellipsis_to_action_label(f.action_forget)
+        add_ellipsis_to_action_label(f.action_grade_now)
 
     def _editor_web_view(self) -> EditorWebView:
         assert self.editor is not None
@@ -691,7 +712,7 @@ class Browser(QMainWindow):
 
     def setupSidebar(self) -> None:
         dw = self.sidebarDockWidget = QDockWidget(tr.browsing_sidebar(), self)
-        dw.setFeatures(QDockWidget.DockWidgetFeature.NoDockWidgetFeatures)
+        dw.setFeatures(QDockWidget.DockWidgetFeature.DockWidgetClosable)
         dw.setObjectName("Sidebar")
         dock_area = (
             Qt.DockWidgetArea.RightDockWidgetArea
@@ -707,6 +728,7 @@ class Browser(QMainWindow):
             self.form.actionSidebarFilter.triggered,
             self.focusSidebarSearchBar,
         )
+        qconnect(dw.visibilityChanged, self.onSidebarVisibilityChange)
         grid = QGridLayout()
         grid.addWidget(self.sidebar.searchBar, 0, 0)
         grid.addWidget(self.sidebar.toolbar, 0, 1)
@@ -725,8 +747,19 @@ class Browser(QMainWindow):
         # UI is more responsive
         self.mw.progress.timer(10, self.sidebar.refresh, False, parent=self.sidebar)
 
-    def showSidebar(self) -> None:
-        self.sidebarDockWidget.setVisible(True)
+    def showSidebar(self, show: bool = True) -> None:
+        self.sidebarDockWidget.setVisible(show)
+
+    def onSidebarVisibilityChange(self, visible):
+        margins = self.form.verticalLayout_3.contentsMargins()
+        skip_left_margin = visible and not (
+            is_mac and aqt.mw.pm.get_widget_style() == WidgetStyle.NATIVE
+        )
+        margins.setLeft(0 if skip_left_margin else margins.right())
+        self.form.verticalLayout_3.setContentsMargins(margins)
+
+        if visible:
+            self.sidebar.refresh()
 
     def focusSidebar(self) -> None:
         self.showSidebar()
@@ -737,10 +770,7 @@ class Browser(QMainWindow):
         self.sidebar.searchBar.setFocus()
 
     def toggle_sidebar(self) -> None:
-        want_visible = not self.sidebarDockWidget.isVisible()
-        self.sidebarDockWidget.setVisible(want_visible)
-        if want_visible:
-            self.sidebar.refresh()
+        self.showSidebar(not self.sidebarDockWidget.isVisible())
 
     # legacy
 
@@ -1080,6 +1110,47 @@ class Browser(QMainWindow):
         ):
             op.run_in_background()
 
+    @no_arg_trigger
+    @skip_if_selection_is_empty
+    @ensure_editor_saved
+    def grade_now(self) -> None:
+        """Show dialog to grade selected cards."""
+        dialog = QDialog(self)
+        dialog.setWindowTitle(tr.actions_grade_now())
+        layout = QHBoxLayout()
+        dialog.setLayout(layout)
+        add_close_shortcut(dialog)
+
+        # Add grade buttons
+        for ease, label in [
+            (1, tr.studying_again()),
+            (2, tr.studying_hard()),
+            (3, tr.studying_good()),
+            (4, tr.studying_easy()),
+        ]:
+            btn = QPushButton(label)
+            qconnect(
+                btn.clicked,
+                functools.partial(
+                    grade_now,
+                    parent=self,
+                    card_ids=self.selected_cards(),
+                    ease=ease,
+                    dialog=dialog,
+                ),
+            )
+            if key := aqt.mw.pm.get_answer_key(ease):
+                QShortcut(key, dialog, activated=btn.click)  # type: ignore
+                btn.setToolTip(tr.actions_shortcut_key(key))
+            layout.addWidget(btn)
+
+        # Add cancel button
+        cancel_btn = QPushButton(tr.actions_cancel())
+        qconnect(cancel_btn.clicked, dialog.reject)
+        layout.addWidget(cancel_btn)
+
+        dialog.exec()
+
     # Edit: selection
     ######################################################################
 
@@ -1187,11 +1258,13 @@ class Browser(QMainWindow):
         self._line_edit().selectAll()
 
     def onNote(self) -> None:
-        assert self.editor is not None
-        assert self.editor.web is not None
+        def cb():
+            assert self.editor is not None and self.editor.web is not None
+            self.editor.web.setFocus()
+            self.editor.loadNote(focusTo=0)
 
-        self.editor.web.setFocus()
-        self.editor.loadNote(focusTo=0)
+        assert self.editor is not None
+        self.editor.call_after_note_saved(cb)
 
     def onCardList(self) -> None:
         self.form.tableView.setFocus()
